diff --git a/core/includes/theme.inc b/core/includes/theme.inc
index 3a8ce65..e2abb01 100644
--- a/core/includes/theme.inc
+++ b/core/includes/theme.inc
@@ -952,14 +952,12 @@ function theme_get_setting($setting_name, $theme = NULL) {
       }
 
       // Generate the path to the logo image.
-      if ($cache[$theme]->get('features.logo')) {
-        $logo_path = $cache[$theme]->get('logo.path');
-        if ($cache[$theme]->get('logo.use_default')) {
-          $cache[$theme]->set('logo.url', file_create_url(dirname($theme_object->filename) . '/logo.png'));
-        }
-        elseif ($logo_path) {
-          $cache[$theme]->set('logo.url', file_create_url($logo_path));
-        }
+      $logo_path = $cache[$theme]->get('logo.path');
+      if ($cache[$theme]->get('logo.use_default')) {
+        $cache[$theme]->set('logo.url', file_create_url(dirname($theme_object->filename) . '/logo.png'));
+      }
+      elseif ($logo_path) {
+        $cache[$theme]->set('logo.url', file_create_url($logo_path));
       }
 
       // Generate the path to the favicon.
@@ -2149,8 +2147,8 @@ function template_preprocess_page(&$variables) {
   $variables['main_menu']         = theme_get_setting('features.main_menu') ? menu_main_menu() : array();
   $variables['secondary_menu']    = theme_get_setting('features.secondary_menu') ? menu_secondary_menu() : array();
   $variables['action_links']      = menu_get_local_actions();
-  $variables['site_name']         = (theme_get_setting('features.name') ? String::checkPlain($site_config->get('name')) : '');
-  $variables['site_slogan']       = (theme_get_setting('features.slogan') ? filter_xss_admin($site_config->get('slogan')) : '');
+  $variables['site_name']         = String::checkPlain($site_config->get('name'));
+  $variables['site_slogan']       = filter_xss_admin($site_config->get('slogan'));
   $variables['tabs']              = menu_local_tabs();
 
   if (isset($variables['page']['#title'])) {
@@ -2374,8 +2372,8 @@ function template_preprocess_maintenance_page(&$variables) {
   $variables['help']              = '';
   $variables['language']          = $language_interface;
   $variables['logo']              = theme_get_setting('logo.url');
-  $variables['site_name']         = (theme_get_setting('features.name') ? String::checkPlain($site_name) : '');
-  $variables['site_slogan']       = (theme_get_setting('features.slogan') ? filter_xss_admin($site_slogan) : '');
+  $variables['site_name']         = String::checkPlain($site_name);
+  $variables['site_slogan']       = filter_xss_admin($site_slogan);
 
   // Compile a list of classes that are going to be applied to the body element.
   $variables['attributes']['class'][] = 'maintenance-page';
diff --git a/core/lib/Drupal/Core/Extension/ThemeHandler.php b/core/lib/Drupal/Core/Extension/ThemeHandler.php
index e2bf62e..6cb773d 100644
--- a/core/lib/Drupal/Core/Extension/ThemeHandler.php
+++ b/core/lib/Drupal/Core/Extension/ThemeHandler.php
@@ -25,10 +25,7 @@ class ThemeHandler implements ThemeHandlerInterface {
    * @var array
    */
   protected $defaultFeatures = array(
-    'logo',
     'favicon',
-    'name',
-    'slogan',
     'node_user_picture',
     'comment_user_picture',
     'comment_user_verification',
@@ -253,7 +250,8 @@ public function rebuildThemeData() {
         'sidebar_first' => 'Left sidebar',
         'sidebar_second' => 'Right sidebar',
         'content' => 'Content',
-        'header' => 'Header',
+        'header_first' => 'Header first',
+        'header_second' => 'Header second',
         'footer' => 'Footer',
         'highlighted' => 'Highlighted',
         'help' => 'Help',
diff --git a/core/modules/block/lib/Drupal/block/Tests/BlockRenderOrderTest.php b/core/modules/block/lib/Drupal/block/Tests/BlockRenderOrderTest.php
index 0521aa9..5941859 100644
--- a/core/modules/block/lib/Drupal/block/Tests/BlockRenderOrderTest.php
+++ b/core/modules/block/lib/Drupal/block/Tests/BlockRenderOrderTest.php
@@ -43,7 +43,7 @@ function setUp() {
    */
   function testBlockRenderOrder() {
     // Enable test blocks and place them in the same region.
-    $region = 'header';
+    $region = 'header_second';
     $test_blocks = array(
       'stark_powered' => array(
         'weight' => '-3',
diff --git a/core/modules/block/lib/Drupal/block/Tests/BlockSystemBrandingTest.php b/core/modules/block/lib/Drupal/block/Tests/BlockSystemBrandingTest.php
index 192d8fc..9a74e94 100644
--- a/core/modules/block/lib/Drupal/block/Tests/BlockSystemBrandingTest.php
+++ b/core/modules/block/lib/Drupal/block/Tests/BlockSystemBrandingTest.php
@@ -40,7 +40,7 @@ public function setUp() {
       ->set('slogan', 'Community plumbing')
       ->save();
     // Add the system branding block to the page.
-    $this->drupalPlaceBlock('system_branding_block', array('region' => 'header', 'id' => 'site-branding'));
+    $this->drupalPlaceBlock('system_branding_block', array('region' => 'header_second', 'id' => 'site-branding'));
   }
 
   /**
diff --git a/core/modules/block/lib/Drupal/block/Tests/BlockTest.php b/core/modules/block/lib/Drupal/block/Tests/BlockTest.php
index e7b99e1..2a138e4 100644
--- a/core/modules/block/lib/Drupal/block/Tests/BlockTest.php
+++ b/core/modules/block/lib/Drupal/block/Tests/BlockTest.php
@@ -104,7 +104,7 @@ function testBlock() {
     $block['id'] = 'system_powered_by_block';
     $block['settings[label]'] = $this->randomName(8);
     $block['theme'] = \Drupal::config('system.theme')->get('default');
-    $block['region'] = 'header';
+    $block['region'] = 'header_second';
 
     // Set block title to confirm that interface works and override any custom titles.
     $this->drupalPostForm('admin/structure/block/add/' . $block['id'] . '/' . $block['theme'], array('settings[label]' => $block['settings[label]'], 'id' => $block['id'], 'region' => $block['region']), t('Save block'));
@@ -224,7 +224,7 @@ function testHideBlockTitle() {
    *   - delta: The block's delta key.
    * @param string $region
    *   The machine name of the theme region to move the block to, for example
-   *   'header' or 'sidebar_first'.
+   *   'header_second' or 'sidebar_first'.
    */
   function moveBlockToRegion(array $block, $region) {
     // Set the created block to a specific region.
@@ -262,8 +262,8 @@ function testBlockRehash() {
     $block = array();
     $block['id'] = 'test_cache';
     $block['theme'] = \Drupal::config('system.theme')->get('default');
-    $block['region'] = 'header';
-    $block = $this->drupalPlaceBlock('test_cache', array('region' => 'header'));
+    $block['region'] = 'header_second';
+    $block = $this->drupalPlaceBlock('test_cache', array('region' => 'header_second'));
 
     // Our test block's caching should default to DRUPAL_CACHE_PER_ROLE.
     $settings = $block->get('settings');
diff --git a/core/modules/block/lib/Drupal/block/Tests/BlockTestBase.php b/core/modules/block/lib/Drupal/block/Tests/BlockTestBase.php
index 39aa634..f9f4abf 100644
--- a/core/modules/block/lib/Drupal/block/Tests/BlockTestBase.php
+++ b/core/modules/block/lib/Drupal/block/Tests/BlockTestBase.php
@@ -60,7 +60,8 @@ function setUp() {
 
     // Define the existing regions.
     $this->regions = array(
-      'header',
+      'header_first',
+      'header_second',
       'sidebar_first',
       'content',
       'sidebar_second',
diff --git a/core/modules/config_translation/lib/Drupal/config_translation/Tests/ConfigTranslationUiTest.php b/core/modules/config_translation/lib/Drupal/config_translation/Tests/ConfigTranslationUiTest.php
index ed4b1e2..cd45ecc 100644
--- a/core/modules/config_translation/lib/Drupal/config_translation/Tests/ConfigTranslationUiTest.php
+++ b/core/modules/config_translation/lib/Drupal/config_translation/Tests/ConfigTranslationUiTest.php
@@ -23,7 +23,7 @@ class ConfigTranslationUiTest extends WebTestBase {
    *
    * @var array
    */
-  public static $modules = array('node', 'contact', 'config_translation', 'config_translation_test', 'views', 'views_ui', 'contextual');
+  public static $modules = array('node', 'contact', 'config_translation', 'config_translation_test', 'views', 'views_ui', 'contextual', 'block');
 
   /**
    * Languages to enable.
@@ -144,6 +144,9 @@ public function testSiteInformationTranslationUi() {
     $this->assertFieldByName('config_names[system.site][name][translation]', $fr_site_name);
     $this->assertFieldByName('config_names[system.site][slogan][translation]', $fr_site_slogan);
 
+    // Place branding block with site name and slogan into header_first region.
+    $this->drupalPlaceBlock('system_branding_block', array('region' => 'header_first'));
+
     // Check French translation of site name and slogan are in place.
     $this->drupalGet('fr');
     $this->assertRaw($fr_site_name);
diff --git a/core/modules/language/lib/Drupal/language/Tests/LanguageUILanguageNegotiationTest.php b/core/modules/language/lib/Drupal/language/Tests/LanguageUILanguageNegotiationTest.php
index 89832f3..7652a2b 100644
--- a/core/modules/language/lib/Drupal/language/Tests/LanguageUILanguageNegotiationTest.php
+++ b/core/modules/language/lib/Drupal/language/Tests/LanguageUILanguageNegotiationTest.php
@@ -389,6 +389,9 @@ function testUrlLanguageFallback() {
     // it is set by JavaScript.
     $this->drupalLogout();
 
+    // Place a site branding block in the header_first region.
+    $this->drupalPlaceBlock('system_branding_block', array('region' => 'header_first'));
+
     // Access the front page without specifying any valid URL language prefix
     // and having as browser language preference a non-default language.
     $http_header = array("Accept-Language: $langcode_browser_fallback;q=1");
@@ -402,7 +405,7 @@ function testUrlLanguageFallback() {
     $this->assertTrue($fields[0] == $languages[$langcode_browser_fallback]->name, 'The browser language is the URL active language');
 
     // Check that URLs are rewritten using the given browser language.
-    $fields = $this->xpath('//strong[@class="site-name"]/a[@rel="home" and @href=:url]', $args);
+    $fields = $this->xpath('//div[@class="site-name"]/a[@rel="home" and @href=:url]', $args);
     $this->assertTrue($fields[0] == 'Drupal', 'URLs are rewritten using the browser language.');
   }
 
diff --git a/core/modules/system/config/schema/system.schema.yml b/core/modules/system/config/schema/system.schema.yml
index 6b82e60..09d5acb 100644
--- a/core/modules/system/config/schema/system.schema.yml
+++ b/core/modules/system/config/schema/system.schema.yml
@@ -431,12 +431,6 @@ system.theme.global:
         favicon:
           type: boolean
           label: 'Shortcut icon'
-        logo:
-          type: boolean
-          label: 'Logo'
-        name:
-          type: boolean
-          label: 'Site name'
         node_user_picture:
           type: boolean
           label: 'User pictures in posts'
@@ -446,9 +440,6 @@ system.theme.global:
         secondary_menu:
           type: boolean
           label: 'Secondary menu'
-        slogan:
-          type: boolean
-          label: 'Site slogan'
     logo:
       type: mapping
       label: 'Shortcut icon settings'
diff --git a/core/modules/system/config/system.theme.global.yml b/core/modules/system/config/system.theme.global.yml
index 13036bf..41682e9 100644
--- a/core/modules/system/config/system.theme.global.yml
+++ b/core/modules/system/config/system.theme.global.yml
@@ -7,12 +7,9 @@ features:
   comment_user_picture: true
   comment_user_verification: true
   favicon: true
-  logo: true
-  name: true
   node_user_picture: true
   main_menu: true
   secondary_menu: true
-  slogan: true
 logo:
   path: ''
   url: ''
diff --git a/core/modules/system/lib/Drupal/system/Form/ThemeSettingsForm.php b/core/modules/system/lib/Drupal/system/Form/ThemeSettingsForm.php
index 2f910ae..b104a06 100644
--- a/core/modules/system/lib/Drupal/system/Form/ThemeSettingsForm.php
+++ b/core/modules/system/lib/Drupal/system/Form/ThemeSettingsForm.php
@@ -97,9 +97,6 @@ public function buildForm(array $form, array &$form_state, $theme = '') {
 
     // Toggle settings
     $toggles = array(
-      'logo' => t('Logo'),
-      'name' => t('Site name'),
-      'slogan' => t('Site slogan'),
       'node_user_picture' => t('User pictures in posts'),
       'comment_user_picture' => t('User pictures in comments'),
       'comment_user_verification' => t('User verification status in comments'),
diff --git a/core/modules/system/lib/Drupal/system/Tests/System/PageTitleTest.php b/core/modules/system/lib/Drupal/system/Tests/System/PageTitleTest.php
index 33f2f47..11241f8 100644
--- a/core/modules/system/lib/Drupal/system/Tests/System/PageTitleTest.php
+++ b/core/modules/system/lib/Drupal/system/Tests/System/PageTitleTest.php
@@ -17,7 +17,7 @@ class PageTitleTest extends WebTestBase {
    *
    * @var array
    */
-  public static $modules = array('node', 'test_page_test', 'form_test');
+  public static $modules = array('node', 'test_page_test', 'form_test', 'block');
 
   protected $content_user;
   protected $saved_title;
@@ -95,8 +95,6 @@ function testTitleXSS() {
 
     // Activate needed appearance settings.
     $edit = array(
-      'toggle_name'           => TRUE,
-      'toggle_slogan'         => TRUE,
       'toggle_main_menu'      => TRUE,
       'toggle_secondary_menu' => TRUE,
     );
@@ -109,6 +107,9 @@ function testTitleXSS() {
     );
     $this->drupalPostForm('admin/config/system/site-information', $edit, t('Save configuration'));
 
+    // Place branding block with site name and slogan into header_first region.
+    $this->drupalPlaceBlock('system_branding_block', array('region' => 'header_first'));
+
     // Load frontpage.
     $this->drupalGet('');
 
diff --git a/core/modules/system/system.module b/core/modules/system/system.module
index edc8532..b301931 100644
--- a/core/modules/system/system.module
+++ b/core/modules/system/system.module
@@ -1532,10 +1532,7 @@ function system_rebuild_theme_data() {
  */
 function _system_default_theme_features() {
   return array(
-    'logo',
     'favicon',
-    'name',
-    'slogan',
     'node_user_picture',
     'comment_user_picture',
     'comment_user_verification',
diff --git a/core/modules/system/templates/page.html.twig b/core/modules/system/templates/page.html.twig
index 1f6f916..b210e29 100644
--- a/core/modules/system/templates/page.html.twig
+++ b/core/modules/system/templates/page.html.twig
@@ -66,33 +66,9 @@
 <div class="l-container">
 
   <header role="banner">
-    {% if logo %}
-      <a href="{{ front_page }}" title="{{ 'Home'|t }}" rel="home">
-        <img src="{{ logo }}" alt="{{ 'Home'|t }}"/>
-      </a>
-    {% endif %}
+    {{ page.header_first }}
 
-    {% if site_name or site_slogan %}
-      <div class="name-and-slogan">
-
-        {# Use h1 when the content title is empty #}
-        {% if title %}
-          <strong class="site-name">
-            <a href="{{ front_page }}" title="{{ 'Home'|t }}" rel="home">{{ site_name }}</a>
-          </strong>
-        {% else %}
-          <h1 class="site-name">
-            <a href="{{ front_page }}" title="{{ 'Home'|t }}" rel="home">{{ site_name }}</a>
-          </h1>
-        {% endif %}
-
-        {% if site_slogan %}
-          <div class="site-slogan">{{ site_slogan }}</div>
-        {% endif %}
-      </div>{# ./name-and-slogan #}
-   {% endif %}
-
-    {{ page.header }}
+    {{ page.header_second }}
   </header>
 
   {% if main_menu or secondary_menu %}
diff --git a/core/profiles/standard/config/block.block.bartik_branding.yml b/core/profiles/standard/config/block.block.bartik_branding.yml
new file mode 100644
index 0000000..9d9b1ee
--- /dev/null
+++ b/core/profiles/standard/config/block.block.bartik_branding.yml
@@ -0,0 +1,22 @@
+id: bartik_branding
+theme: bartik
+weight: 0
+status: true
+langcode: en
+region: header_first
+plugin: system_branding_block
+settings:
+  label: 'Page Site Branding'
+  module: system
+  label_display: '0'
+  cache: -1
+visibility:
+  path:
+    visibility: 0
+    pages: ''
+  role:
+    roles: {  }
+  node_type:
+    types:
+      article: '0'
+      page: '0'
diff --git a/core/themes/bartik/bartik.info.yml b/core/themes/bartik/bartik.info.yml
index 6851a12..e6b29b6 100644
--- a/core/themes/bartik/bartik.info.yml
+++ b/core/themes/bartik/bartik.info.yml
@@ -14,8 +14,9 @@ stylesheets:
 ckeditor_stylesheets:
   - css/ckeditor-iframe.css
 regions:
-  header: Header
-  help: Help
+  header_first: 'Header first'
+  header_second: 'Header second'
+  help: 'Help'
   page_top: 'Page top'
   page_bottom: 'Page bottom'
   highlighted: Highlighted
diff --git a/core/themes/bartik/css/colors.css b/core/themes/bartik/css/colors.css
index 324215a..88ca046 100644
--- a/core/themes/bartik/css/colors.css
+++ b/core/themes/bartik/css/colors.css
@@ -50,12 +50,12 @@ a:active,
 #footer-wrapper {
   background: #292929;
 }
-.region-header,
-.region-header a,
-.region-header li a.active,
-#name-and-slogan,
+[class*="region-header-"],
+[class*="region-header-"] a,
+[class*="region-header-"] li a.active,
+.site-branding-text,
 .site-branding-block,
-#name-and-slogan a,
+.site-branding-text a,
 .site-branding-block a,
 #secondary-menu-links li a {
   color: #fffeff;
diff --git a/core/themes/bartik/css/layout.css b/core/themes/bartik/css/layout.css
index 74f015b..0a8dda7 100644
--- a/core/themes/bartik/css/layout.css
+++ b/core/themes/bartik/css/layout.css
@@ -24,12 +24,20 @@ body,
 #header div.section {
   position: relative;
 }
-.region-header {
-  float: right; /* LTR */
+.region-header-second {
   margin: .5em 5px .75em;
   border: 1px solid #ccc;
 }
-[dir="rtl"] .region-header {
+.region-header-first {
+  float: left; /* LTR */
+}
+.region-header-second {
+  float: right; /* LTR */
+}
+[dir="rtl"] .region-header-first {
+  float: right;
+}
+[dir="rtl"] .region-header-second {
   float: left;
 }
 #secondary-menu {
diff --git a/core/themes/bartik/css/maintenance-page.css b/core/themes/bartik/css/maintenance-page.css
index e0c79c6..71df23e 100644
--- a/core/themes/bartik/css/maintenance-page.css
+++ b/core/themes/bartik/css/maintenance-page.css
@@ -31,16 +31,15 @@ body.maintenance-page {
   background-color: #fff;
   background-image: none;
 }
-.maintenance-page #name-and-slogan {
+.maintenance-page .site-branding-text {
   margin-bottom: 50px;
   margin-left: 0;
   padding-top: 20px;
   font-size: 90%;
 }
-.maintenance-page #name-and-slogan,
-.maintenance-page #name-and-slogan a,
-.maintenance-page #name-and-slogan a:hover,
-.maintenance-page #name-and-slogan a:hover {
+.maintenance-page .site-branding-text,
+.maintenance-page .site-branding-text a,
+.maintenance-page .site-branding-text a:hover {
   color: #777;
 }
 .maintenance-page  h1#page-title {
diff --git a/core/themes/bartik/css/style.css b/core/themes/bartik/css/style.css
index 69a382c..be75fa7 100644
--- a/core/themes/bartik/css/style.css
+++ b/core/themes/bartik/css/style.css
@@ -105,7 +105,6 @@ pre {
 /* ------------------ Fonts ------------------ */
 
 body,
-#site-slogan,
 .site-slogan,
 #page .ui-widget,
 .comment-form label,
@@ -343,42 +342,32 @@ ul.tips {
 .skip-link:focus {
   outline: 0;
 }
-#logo,
 .site-logo {
   float: left; /* LTR */
   padding-left: 5px; /* LTR */
 }
-[dir="rtl"] #logo,
 [dir="rtl"] .site-logo {
   padding: 15px 10px 15px 15px;
 }
-
-#name-and-slogan,
 .site-branding-text {
   float: left; /* LTR */
   margin: 0;
   padding: 5px 10px 8px;
 }
-[dir="rtl"] #name-and-slogan,
 [dir="rtl"] .site-branding-text {
   margin: 0 15px 30px 0;
 }
-
-#site-name,
 .site-name {
   font-size: 1.6em;
   color: #686868;
   line-height: 1;
 }
-h1#site-name,
 h1.site-name {
   margin: 0;
 }
-#site-name a,
 .site-name a {
   font-weight: normal;
 }
-#site-slogan,
 .site-slogan {
   font-size: 0.929em;
   margin-top: 7px;
@@ -386,33 +375,36 @@ h1.site-name {
   font-style: italic;
 }
 /* Region header blocks. */
-.region-header .block {
-  font-size: 0.857em;
+[class*="region-header-"] .block {
   float: left; /* LTR */
-  margin: 0 10px;
+  margin: 0;
   padding: 0;
 }
-.region-header .block > h2 {
+.region-header-second .block {
+    font-size: 0.857em;
+    margin: 0 10px;
+}
+[class*="region-header-"] .block > h2 {
   /* @extend .visually-hidden */
   position: absolute !important;
   clip: rect(1px, 1px, 1px, 1px);
   overflow: hidden;
   height: 1px;
 }
-.region-header .block .content {
+[class*="region-header-"] .block .content {
   margin: 0;
   padding: 0;
 }
-.region-header .block ul {
+[class*="region-header-"] .block ul {
   margin: 0;
   padding: 0;
 }
-.region-header .block li {
+[class*="region-header-"] .block li {
   list-style: none;
   list-style-image: none;
   padding: 0;
 }
-.region-header .form-text {
+[class*="region-header-"] .form-text {
   background: #fefefe;
   background: rgba(255, 255, 255, 0.7);
   border-color: #ccc;
@@ -420,89 +412,89 @@ h1.site-name {
   margin-right: 2px; /* LTR */
   width: 120px;
 }
-[dir="rtl"] .region-header .form-text {
+[dir="rtl"] [class*="region-header-"] .form-text {
   margin-left: 2px;
   margin-right: 0;
 }
-.region-header .form-text:hover,
-.region-header .form-text:focus,
-.region-header .form-text:active {
+[class*="region-header-"] .form-text:hover,
+[class*="region-header-"] .form-text:focus,
+[class*="region-header-"] .form-text:active {
   background: #fff;
   background: rgba(255, 255, 255, 0.8);
 }
-.region-header .form-required {
+[class*="region-header-"] .form-required {
   color: #eee;
   color: rgba(255, 255, 255, 0.7);
 }
-/* Region header block menus. */
-.region-header .block-menu {
+/* Block menus in header regions. */
+[class*="region-header-"] .block-menu {
   border: 1px solid;
   border-color: #eee;
   border-color: rgba(255, 255, 255, 0.2);
   padding: 0;
   width: 208px;
 }
-.region-header .block-menu li a {
+[class*="region-header-"] .block-menu li a {
   display: block;
   border-bottom: 1px solid;
   border-bottom-color: #eee;
   border-bottom-color: rgba(255, 255, 255, 0.2);
   padding: 3px 7px;
 }
-.region-header .block-menu li a:hover,
-.region-header .block-menu li a:focus,
-.region-header .block-menu li a:active {
+[class*="region-header-"] .block-menu li a:hover,
+[class*="region-header-"] .block-menu li a:focus,
+[class*="region-header-"] .block-menu li a:active {
   text-decoration: none;
   background: rgba(255, 255, 255, 0.15);
 }
-.region-header .block-menu li:last-child a {
+[class*="region-header-"] .block-menu li:last-child a {
   border-bottom: 0;
 }
-/* User Login block in the header region */
-.region-header #block-user-login {
+/* User Login block in header regions. */
+[class*="region-header-"] #block-user-login {
   width: auto;
 }
-.region-header #block-user-login .content {
+[class*="region-header-"] #block-user-login .content {
   margin-top: 2px;
 }
-.region-header #block-user-login .form-item {
+[class*="region-header-"] #block-user-login .form-item {
   float: left; /* LTR */
   margin: 0;
   padding: 0;
 }
-.region-header #block-user-login div.item-list,
-.region-header #block-user-login div.description {
+[class*="region-header-"] #block-user-login div.item-list,
+[class*="region-header-"] #block-user-login div.description {
   font-size: 0.916em;
   margin: 0;
 }
-.region-header #block-user-login div.item-list {
+[class*="region-header-"] #block-user-login div.item-list {
   clear: both;
 }
-.region-header #block-user-login div.description {
+[class*="region-header-"] #block-user-login div.description {
   display: inline;
 }
-.region-header #block-user-login .item-list ul {
+[class*="region-header-"] #block-user-login .item-list ul {
   padding: 0;
   line-height: 1;
 }
-.region-header #block-user-login .item-list li {
+[class*="region-header-"] #block-user-login .item-list li{
   list-style: none;
   float: left; /* LTR */
   padding: 3px 0 1px;
 }
-.region-header #block-user-login .item-list li:last-child {
+[class*="region-header-"] #block-user-login .item-list li:last-child{
   padding-left: 0.5em; /* LTR */
 }
-[dir="rtl"] .region-header #block-user-login .item-list li:last-child {
+[dir="rtl"] [class*="region-header-"] #block-user-login .item-list li:last-child {
   padding-left: 0;
   padding-right: 0.5em;
 }
-.region-header #block-user-login .form-actions {
+[class*="region-header-"] #block-user-login .form-actions {
   margin: 4px 0 0;
   padding: 0;
   clear: both;
 }
-.region-header #block-user-login input.form-submit {
+[class*="region-header-"] #block-user-login input.form-submit {
   border: 1px solid;
   border-color: #ccc;
   border-color: rgba(255, 255, 255, 0.5);
@@ -511,31 +503,28 @@ h1.site-name {
   margin: 4px 0;
   padding: 3px 8px;
 }
-.region-header #block-user-login input.form-submit:hover,
-.region-header #block-user-login input.form-submit:focus {
+[class*="region-header-"] #block-user-login input.form-submit:hover,
+[class*="region-header-"] #block-user-login input.form-submit:focus {
   background: #fff;
   background: rgba(255, 255, 255, 0.9);
 }
-/* Search block in region header. */
-.region-header #block-search-form {
+/* Search block in region headers. */
+[class*="region-header-"] #block-search-form {
   width: 208px;
 }
-.region-header #block-search-form .form-text {
+[class*="region-header-"] #block-search-form .form-text {
   width: 154px;
 }
-/* Language switcher block in region header. */
-.region-header .block-locale ul li {
+/* Language switcher block in region headers. */
+[class*="region-header-"] .block-locale ul li {
   display: inline;
   padding: 0 0.5em;
 }
-
-[dir="rtl"] #logo,
 [dir="rtl"] .site-logo,
-[dir="rtl"] #name-and-slogan,
 [dir="rtl"] .site-branding-text,
-[dir="rtl"] .region-header .block,
-[dir="rtl"] .region-header #block-user-login .form-item,
-[dir="rtl"] .region-header #block-user-login .item-list li {
+[dir="rtl"] [class*="region-header-"] .block,
+[dir="rtl"] [class*="region-header-"] #block-user-login .form-item,
+[dir="rtl"] [class*="region-header-"] #block-user-login .item-list li {
   float: right;
 }
 
@@ -1765,18 +1754,15 @@ div.admin-panel .description {
 @media all and (min-width: 461px) and (max-width: 900px) {
  /* ------------ Header and Menus -------------------------- */
 
- .region-header {
+  .region-header-second {
     margin: .5em 5px .75em;
   }
-  #logo,
   .site-logo {
     padding: 5px 0 0 5px; /* LTR */
   }
-  [dir="rtl"] #logo,
   [dir="rtl"] .site-logo {
     padding: 5px 5px 0 0;
   }
-  #name-and-slogan,
   .site-branding-text {
     padding: 10px 10px 8px;
   }
@@ -1815,29 +1801,25 @@ div.admin-panel .description {
 
 @media all and (min-width: 901px) {
 
-  .region-header {
+  .region-header-second {
     margin: 1em 5px 1.5em;
   }
-  #logo,
   .site-logo {
     padding: 15px 15px 15px 10px; /* LTR */
   }
-  [dir="rtl"] #logo,
   [dir="rtl"] .site-logo {
     padding: 15px 10px 15px 15px;
   }
-  #name-and-slogan,
   .site-branding-text {
     padding: 26px 0 0;
     margin: 0 0 30px 15px; /* LTR */
   }
-  [dir="rtl"] #name-and-slogan,
   [dir="rtl"] .site-branding-text {
     margin: 0 15px 30px 0;
   }
-  #site-name,
   .site-name {
     font-size: 1.821em;
+    display: block;
   }
   #main-menu-links {
     font-size: 0.929em;
diff --git a/core/themes/bartik/templates/maintenance-page.html.twig b/core/themes/bartik/templates/maintenance-page.html.twig
index b29cafa..192c66f 100644
--- a/core/themes/bartik/templates/maintenance-page.html.twig
+++ b/core/themes/bartik/templates/maintenance-page.html.twig
@@ -19,7 +19,6 @@
   {{ scripts }}
 </head>
 <body class="{{ attributes.class }}"{{ attributes }}>
-
   <a href="#main-content" class="visually-hidden focusable skip-link">
     {{ 'Skip to main content'|t }}
   </a>
@@ -27,22 +26,7 @@
   <div id="page-wrapper"><div id="page">
 
     <header id="header" role="banner"><div class="section clearfix">
-      {% if site_name or site_slogan %}
-        <div id="name-and-slogan"{{ hide_site_name and hide_site_slogan ? ' class="visually-hidden"' }}>
-          {% if site_name %}
-            <div id="site-name"{{ hide_site_name ? ' class="visually-hidden"' }}>
-              <strong>
-                <a href="{{ front_page }}" title="{{ 'Home'|t }}" rel="home"><span>{{ site_name }}</span></a>
-              </strong>
-            </div>
-          {% endif %}
-          {% if site_slogan %}
-            <div id="site-slogan"{{ hide_site_slogan ? ' class="visually-hidden"' }}>
-              {{ site_slogan }}
-            </div>
-          {% endif %}
-        </div> <!-- /#name-and-slogan -->
-      {% endif %}
+      {{ page.header_first }}
     </div></header> <!-- /.section, /#header -->
 
     <div id="main-wrapper"><div id="main" class="clearfix">
diff --git a/core/themes/bartik/templates/page.html.twig b/core/themes/bartik/templates/page.html.twig
index 5602997..2d5c1aa 100644
--- a/core/themes/bartik/templates/page.html.twig
+++ b/core/themes/bartik/templates/page.html.twig
@@ -56,7 +56,8 @@
  *   comment/reply/12345).
  *
  * Regions:
- * - page.header: Items for the header region.
+ * - page.header_first: Items for the first header region.
+ * - page.header_second: Items for the second header region.
  * - page.featured: Items for the featured region.
  * - page.highlighted: Items for the highlighted content region.
  * - page.help: Dynamic help text, mostly for admin pages.
@@ -82,44 +83,15 @@
 <div id="page-wrapper"><div id="page">
 
   <header id="header" class="{{ secondary_menu ? 'with-secondary-menu' : 'without-secondary-menu' }}" role="banner"><div class="section clearfix">
-   {% if secondary_menu %}
+    {% if secondary_menu %}
       <nav id="secondary-menu" class="navigation" role="navigation">
         {{ secondary_menu }}
       </nav> <!-- /#secondary-menu -->
     {% endif %}
 
-    {% if logo %}
-      <a href="{{ front_page }}" title="{{ 'Home'|t }}" rel="home" id="logo">
-        <img src="{{ logo }}" alt="{{ 'Home'|t }}" />
-      </a>
-    {% endif %}
-
-    {% if site_name or site_slogan %}
-      <div id="name-and-slogan"{% if hide_site_name and hide_site_slogan %} class="visually-hidden"{% endif %}>
-        {% if site_name %}
-          {% if title %}
-            <div id="site-name"{% if hide_site_name %} class="visually-hidden"{% endif %}>
-              <strong>
-                <a href="{{ front_page }}" title="{{ 'Home'|t }}" rel="home"><span>{{ site_name }}</span></a>
-              </strong>
-            </div>
-          {# Use h1 when the content title is empty #}
-          {% else %}
-            <h1 id="site-name"{% if hide_site_name %} class="visually-hidden" {% endif %}>
-              <a href="{{ front_page }}" title="{{ 'Home'|t }}" rel="home"><span>{{ site_name }}</span></a>
-            </h1>
-          {% endif %}
-        {% endif %}
-
-        {% if site_slogan %}
-          <div id="site-slogan"{% if hide_site_slogan %} class="visually-hidden"{% endif %}>
-            {{ site_slogan }}
-          </div>
-        {% endif %}
-      </div><!-- /#name-and-slogan -->
-    {% endif %}
+    {{ page.header_first }}
 
-    {{ page.header }}
+    {{ page.header_second }}
 
     {% if main_menu %}
       <nav id ="main-menu" class="navigation" role="navigation">

diff --git a/core/modules/block/lib/Drupal/block/Tests/BlockUiTest.php b/core/modules/block/lib/Drupal/block/Tests/BlockUiTest.php
index 356d480..680895a 100644
--- a/core/modules/block/lib/Drupal/block/Tests/BlockUiTest.php
+++ b/core/modules/block/lib/Drupal/block/Tests/BlockUiTest.php
@@ -70,7 +70,7 @@ function setUp() {
       ),
       array(
         'label' => 'Powered by Drupal',
-        'tr' => '12',
+        'tr' => '14',
         'plugin_id' => 'system_powered_by_block',
         'settings' => array('region' => 'footer', 'id' => 'powered'),
         'test_weight' => '0',
@@ -110,8 +110,8 @@ function testBlockAdminUiPage() {
       $this->assertTrue((string) $element[0] == $label, 'The "' . $label . '" block title is set inside the ' . $values['settings']['region'] . ' region.');
       // Look for a test block region select form element.
       $this->assertField('blocks[' . $values['settings']['id'] . '][region]', 'The block "' . $values['label'] . '" has a region assignment field.');
-      // Move the test block to the header region.
-      $edit['blocks[' . $values['settings']['id'] . '][region]'] = 'header';
+      // Move the test block to the header_second region.
+      $edit['blocks[' . $values['settings']['id'] . '][region]'] = 'header_second';
       // Look for a test block weight select form element.
       $this->assertField('blocks[' . $values['settings']['id'] . '][weight]', 'The block "' . $values['label'] . '" has a weight assignment field.');
       // Change the test block's weight.
@@ -122,8 +122,8 @@ function testBlockAdminUiPage() {
       // Check if the region and weight settings changes have persisted.
       $this->assertOptionSelected(
         'edit-blocks-' . $values['settings']['id']  . '-region',
-        'header',
-        'The block "' . $label . '" has the correct region assignment (header).'
+        'header_second',
+        'The block "' . $label . '" has the correct region assignment (header_second).'
       );
       $this->assertOptionSelected(
         'edit-blocks-' . $values['settings']['id']  . '-weight',
diff --git a/core/modules/system/lib/Drupal/system/Tests/System/ThemeTest.php b/core/modules/system/lib/Drupal/system/Tests/System/ThemeTest.php
index 520cb11..09ab2d1 100644
--- a/core/modules/system/lib/Drupal/system/Tests/System/ThemeTest.php
+++ b/core/modules/system/lib/Drupal/system/Tests/System/ThemeTest.php
@@ -114,9 +114,10 @@ function testThemeSettings() {
       $this->assertEqual((string) $elements[1], $explicit_file);
       $this->assertEqual((string) $elements[2], $local_file);
 
-      // Verify the actual 'src' attribute of the logo being output.
+      // Verify the actual 'src' attribute of the logo being output in a site branding block.
+      $this->drupalPlaceBlock('system_branding_block', array('region' => 'header_first'));
       $this->drupalGet('');
-      $elements = $this->xpath('//header/a[@rel=:rel]/img', array(
+      $elements = $this->xpath('//header//a[@rel=:rel]/img', array(
           ':rel' => 'home',
         )
       );
@@ -166,8 +167,9 @@ function testThemeSettings() {
     $fields = $this->xpath($this->constructFieldXpath('name', 'logo_path'));
     $uploaded_filename = 'public://' . $fields[0]['value'];
 
+    $this->drupalPlaceBlock('system_branding_block', array('region' => 'header_first'));
     $this->drupalGet('');
-    $elements = $this->xpath('//header/a[@rel=:rel]/img', array(
+    $elements = $this->xpath('//header//a[@rel=:rel]/img', array(
         ':rel' => 'home',
       )
     );